======================
sphinxcontrib-cadquery
======================

|pypi-version| |lint-status| |test-status| |docs-status|


A `Sphinx`_ extension for rendering `CadQuery`_ models.


.. _Sphinx: https://www.sphinx-doc.org/
.. _CadQuery: https://cadquery.readthedocs.io/


.. |pypi-version| image:: https://img.shields.io/pypi/v/sphinxcontrib-cadquery
    :target: https://pypi.org/project/sphinxcontrib-cadquery/
    :alt: PyPI version
.. |lint-status| image:: https://github.com/sethfischer/sphinxcontrib-cadquery/actions/workflows/lint.yml/badge.svg
    :target: https://github.com/sethfischer/sphinxcontrib-cadquery/actions/workflows/lint.yml
    :alt: Lint status
.. |test-status| image:: https://github.com/sethfischer/sphinxcontrib-cadquery/actions/workflows/test.yml/badge.svg
    :target: https://github.com/sethfischer/sphinxcontrib-cadquery/actions/workflows/test.yml
    :alt: Test status
.. |docs-status| image:: https://readthedocs.org/projects/sphinxcontrib-cadquery/badge/?version=latest
    :target: https://sphinxcontrib-cadquery.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation status
